@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: scene.R 970 2013-09-16 01:18:23Z murdoch $
+## $Id: scene.R 979 2013-10-06 14:54:36Z murdoch $
 ##
 
 ##
@@ -27,7 +27,7 @@ rgl.clear <- function( type = "shapes" )
   idata <- as.integer(c(length(type), type))
  
   ret <- .C( rgl_clear, 
-    success = as.integer(FALSE),
+    success = FALSE,
     idata
   )
   
@@ -56,7 +56,7 @@ rgl.pop <- function( type = "shapes", id = 0)
     idata <- as.integer(c(type, i))
 
     ret <- .C( rgl_pop,
-      success = as.integer(FALSE),
+      success = FALSE,
       idata
     )
 
@@ -168,7 +168,7 @@ rgl.viewpoint <- function( theta = 0.0, phi = 15.0, fov = 60.0, zoom = 1.0, scal
   ddata <- as.numeric(c(theta,phi,fov,zoom,scale,userMatrix[1:16]))
 
   ret <- .C( rgl_viewpoint,
-    success = as.integer(FALSE),
+    success = FALSE,
     idata,
     ddata
   )
@@ -191,7 +191,7 @@ rgl.bg <- function(sphere=FALSE, fogtype="none", color=c("black","white"), back=
   idata   <- as.integer(c(sphere,fogtype))
 
   ret <- .C( rgl_bg, 
-    success = as.integer(FALSE),
+    success = FALSE,
     idata
   )
 
@@ -256,7 +256,7 @@ rgl.bbox <- function(
   ddata <- as.numeric(c(xunit, yunit, zunit, marklen, expand))
 
   ret <- .C( rgl_bbox,
-    success = as.integer(FALSE),
+    success = FALSE,
     idata,
     ddata,
     as.numeric(xat),
@@ -707,7 +707,7 @@ rgl.user2window <- function( x, y=NULL, z=NULL, projection = rgl.projection())
   idata  <- as.integer(ncol(points))
   
   ret <- .C( rgl_user2window,
-  	success = as.integer(FALSE),
+  	success = FALSE,
 	idata,
 	as.double(points),
 	window=double(length(points)),
@@ -732,7 +732,7 @@ rgl.window2user <- function( x, y = NULL, z = 0, projection = rgl.projection())
   idata  <- as.integer(ncol(window))
   
   ret <- .C( rgl_window2user,
-  	success = as.integer(FALSE),
+  	success = FALSE,
 	idata,
 	point=double(length(window)),
 	window,
@@ -755,7 +755,7 @@ msABORT    <- 4
 rgl.selectstate <- function()
 {
 	ret <- .C( rgl_selectstate,
-    	success = as.integer(FALSE),
+    	success = FALSE,
     	state = as.integer(0),
     	mouseposition = double(4)
   	)
@@ -792,7 +792,7 @@ rgl.setselectstate <- function(state = "current")
 	idata <- as.integer(c(state))
 	
 	  ret <- .C( rgl_setselectstate, 
-	    success = as.integer(FALSE),
+	    success = FALSE,
 	    state = idata
 	  )
 	
