@@ -4,7 +4,8 @@
 #include "scene.h"
 #include "Shape.hpp"
 #include "SphereMesh.hpp"
-#include <map>
+
+namespace rgl {
 
 class SphereSet : public Shape {
 private:
@@ -59,4 +60,6 @@ public:
 
 };
 
+} // namespace rgl
+
 #endif // SPHERESET_HPP
