@@ -1,8 +1,11 @@
 #ifndef TEXTURE_HPP
 #define TEXTURE_HPP
 
+#include "pixmap.h"
 #include "types.h"
 
+namespace rgl {
+
 //
 // CLASS
 //   Texture
@@ -46,4 +49,6 @@ private:
   char*   filename;
 };
 
+} // namespace rgl
+
 #endif // TEXTURE_HPP
