@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: pixmap.cpp 753 2009-03-15 17:41:20Z murdoch $
+// $Id: pixmap.cpp 977 2013-10-04 16:57:22Z murdoch $
 
 using namespace std;
 #include "pixmap.h"
@@ -10,14 +10,18 @@ using namespace std;
 
 // PNG FORMAT IMPLEMENTATION
 
+using namespace rgl;
+
 #ifdef HAVE_PNG_H
 #include "pngpixmap.h"
+namespace rgl {
 PNGPixmapFormat png;
+}
 #endif
 
 // PIXMAP FORMAT TABLE
 
-PixmapFormat* pixmapFormat[PIXMAP_FILEFORMAT_LAST] =
+PixmapFormat* rgl::pixmapFormat[PIXMAP_FILEFORMAT_LAST] =
 {
   
 // PNG FORMAT
@@ -91,7 +95,7 @@ bool Pixmap::load(const char* filename)
   if (!file) {
     char buffer[256];
     sprintf(buffer, "Pixmap load: unable to open file '%s' for reading", filename);
-    lib::printMessage(buffer);
+    printMessage(buffer);
     return false;
   }
 
@@ -111,11 +115,11 @@ bool Pixmap::load(const char* filename)
   }
 
   if (!support) {
-    lib::printMessage("Pixmap load: file format unsupported");
+    printMessage("Pixmap load: file format unsupported");
   }
   
   if (!success) {
-    lib::printMessage("Pixmap load: failed");
+    printMessage("Pixmap load: failed");
   }
 
   fclose(file);
@@ -132,7 +136,7 @@ bool Pixmap::save(PixmapFormat* format, const char* filename)
   if (!file) {
     char buffer[256];
     sprintf(buffer, "Pixmap save: unable to open file '%s' for writing", filename);
-    lib::printMessage(buffer);
+    printMessage(buffer);
     return false;
   }
   
