@@ -4,11 +4,13 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: pixmap.h 586 2007-08-03 19:47:16Z dmurdoch $
+// $Id: pixmap.h 976 2013-10-04 15:06:19Z murdoch $
 
 #include <cstdio>
 #include "opengl.hpp"
 
+namespace rgl {
+
 class PixmapFormat;
   
 enum PixmapTypeID { INVALID=0, RGB24, RGB32, RGBA32, GRAY8 };
@@ -46,4 +48,6 @@ public:
 
 extern PixmapFormat* pixmapFormat[PIXMAP_FILEFORMAT_LAST];
 
+} // namespace rgl
+
 #endif /* PIXMAP_H */
