@@ -1,13 +1,14 @@
 #ifndef RGL_W32_GUI_HPP
 #define RGL_W32_GUI_HPP
 // ---------------------------------------------------------------------------
-// $Id: win32gui.hpp 840 2012-01-06 16:07:37Z murdoch $
+// $Id: win32gui.hpp 976 2013-10-04 15:06:19Z murdoch $
 // ---------------------------------------------------------------------------
 #include "gui.hpp"
 // ---------------------------------------------------------------------------
 #include <windows.h>
-// ---------------------------------------------------------------------------
-namespace gui {
+
+namespace rgl {
+
 // ---------------------------------------------------------------------------
 class Win32GUIFactory : public GUIFactory
 {
@@ -20,7 +21,8 @@ public:
 #endif
 };
 // ---------------------------------------------------------------------------
-} // namespace gui
-// ---------------------------------------------------------------------------
+
+} // namespace rgl
+
 #endif // RGL_W32_GUI_HPP
 
